@@ -10,7 +10,9 @@ from Products.CMFCore import utils as cmfutils
 from Products.validation.exceptions import AlreadyRegisteredValidatorError
 
 from plonehrm.contracts import config
-
+from Products.validation import validation
+from validators import MaxDaysPerWeek
+validation.register(MaxDaysPerWeek('maxDaysPerWeek'))
 logger = logging.getLogger('plonehrm.contracts')
 logger.debug('Installing Product')
 ContractsMessageFactory = MessageFactory(u'contract')
