@@ -1,3 +1,4 @@
+from Acquisition import aq_inner
 from DateTime import DateTime
 from kss.core import kssaction, KSSView
 from zope.event import notify
@@ -142,7 +143,7 @@ class ContractKssView(KSSView):
         form = self.request.form
         core = self.getCommandSet('core')
 
-        employee = self.context
+        employee = aq_inner(self.context)
         fields = ['end_employment_reason',
                   'contract_end_employment_date_day',
                   'contract_end_employment_date_month',
